@@ -4,15 +4,18 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#ifndef LAUNCHAPP_H
-#define LAUNCHAPP_H
+#pragma once
 
 #include <QObject>
 #include <QStringList>
 
+#include <qqmlregistration.h>
+
 class LaunchApp : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_SINGLETON
 
 public:
     explicit LaunchApp(QObject *parent = nullptr);
@@ -21,5 +24,3 @@ public Q_SLOTS:
     void launchWizard();
     void launchSendFile(const QString &ubi);
 };
-
-#endif // LAUNCHAPP_H
