@@ -39,9 +39,6 @@ int main(int argc, char *argv[])
                         QStringLiteral("afiestas@kde.org"),
                         QStringLiteral("http://www.afiestas.org/"));
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("preferences-system-bluetooth")));
     app.setQuitOnLastWindowClosed(false);
 
